@@ -15,6 +15,9 @@ proc Backup {fn} {
     global ds9
     global current
 
+    # really need this for geometrey
+    RealizeDS9
+
     set ch {}
     set dir {}
     if {![BackupPreamble $fn ch dir]} {
@@ -30,6 +33,9 @@ proc Backup {fn} {
     # Colorbar
     ColorbarBackup $ch $dir
 
+    # Illustrate
+    IllustrateBackup $ch $dir
+
     # Frames
     foreach ff $ds9(frames) {
 	if {![$ff has iis]} {
@@ -246,6 +252,7 @@ proc Restore {fn} {
       foreach ff $ds9(frames) {
 	set cb ${ff}cb
 	$cb colorbar [$ff get colorbar]
+	set current(colorbar) ${current(frame)}cb
       }
     }
 
@@ -309,7 +316,7 @@ proc BackupFrame {ch which dir} {
     WCSBackup $ch $which $fdir $rdir
 
     # ok, at this point, we must realize the frame, so that all matrices
-    # are valid for pan/zoom/crosshair/markers etc...
+    # are valid for pan/zoom/crosshair/markers etc
     puts $ch "update"
 
     PanZoomBackup $ch $which
@@ -641,6 +648,13 @@ proc BackupGUI {ch} {
     puts $ch "global pblink"
     puts $ch "array set pblink \{ [array get pblink] \}"
 
+    global fade
+    puts $ch "global fade"
+    puts $ch "array set fade \{ [array get fade] \}"
+    global pfade
+    puts $ch "global pfade"
+    puts $ch "array set pfade \{ [array get pfade] \}"
+
     global tile
     puts $ch "global tile"
     puts $ch "array set tile \{ [array get tile] \}"
@@ -839,6 +853,11 @@ proc BackupGUI {ch} {
     global active
     puts $ch "global active"
     puts $ch "array set active \{ [array get active] \}"
+
+    # set window size
+    global ds9
+    puts $ch "global ds9"
+    puts $ch "wm geometry $ds9(top) [winfo width $ds9(top)]x[winfo height $ds9(top)]"
 }
 
 proc ProcessBackupCmd {varname iname} {
