@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -66,7 +66,7 @@ proc UpdateBlock {} {
     UpdateContourScale
     UpdateContourDialog
     UpdateWCSDialog
-    UpdateGraphAxis $current(frame)
+    UpdateGraphAxes $current(frame)
     UpdateMain
 
     UpdateHeaderDialog
@@ -161,7 +161,7 @@ proc BlockApplyDialog {} {
 	RGBEvalLockCurrent rgb(lock,block) [list $current(frame) block to $block(factor)]
 
 	LockFrameCurrent
-	UpdateGraphAxis $current(frame)
+	UpdateGraphAxes $current(frame)
 	UpdateBlockDialog
 	RefreshInfoBox $current(frame)
     }
