@@ -38,10 +38,8 @@ proc CATDef {} {
     set icat(server,menu) { \
 	{{CDS, France} cds} \
 	{{Tokyo, Japan} adac} \
-	{{CADC, Canada} cadc} \
-	{{Cambridge, UK} cambridge} \
 	{{CFA, USA} sao} \
-	{{UKIRT-Hawaii, USA} ukirt} \
+	{{INASAN, Russia} inasan} \
 	{{IUCAA, India} iucaa} \
 	{{Bejing, China} bejing} \
 	{{SAAO, South Africa} saao} \
@@ -969,7 +967,7 @@ proc ProcessCatalogCmd {varname iname} {
     incr i [expr $cat::yycnt-1]
 }
 
-proc ProcessSendCatalogCmd {proc id param sock fn} {
+proc ProcessSendCatalogCmd {proc id param} {
     global icat
 
     set rr {}
@@ -1082,17 +1080,18 @@ proc CatalogCmdSAMPSend {name} {
 	return
     }
 
-    if {[info exists samp]} {
-	foreach arg $samp(apps,votable) {
-	    foreach {key val} $arg {
-		if {[string tolower $val] == $name} {
-		    SAMPSendTableLoadVotable $key $cvarname
-		    break
-		}
+    if {![info exists samp]} {
+	Error [msgcat::mc {SAMP: not connected}]
+	return
+    }
+    
+    foreach arg [SAMPGetAppsVOTable] {
+	foreach {key val} $arg {
+	    if {[string tolower $val] == $name} {
+		SAMPSendTableLoadVotable $key $cvarname
+		break
 	    }
 	}
-    } else {
-	Error [msgcat::mc {SAMP: not connected}]
     }
 }
 
