@@ -15,14 +15,126 @@ proc ColorbarDef {} {
     set icolorbar(top) .clrbar
     set icolorbar(mb) .clrbarmb
 
-    set icolorbar(default,cmaps) [list grey red green blue a b bb he i8 aips0 sls hsv heat cool rainbow standard staircase color]
+    set icolorbar(default,cmaps) [list \
+				      grey \
+				      red \
+				      green \
+				      blue \
+				      a \
+				      b \
+				      bb \
+				      he \
+				      i8 \
+				      aips0 \
+				      sls \
+				      hsv \
+				      heat \
+				      cool \
+				      rainbow \
+				      standard \
+				      staircase \
+				      color \
+				     ]
 
-    set icolorbar(h5,cmaps) [list h5_autumn h5_bluered h5_bone h5_cool h5_copper h5_dkbluered h5_gray h5_green h5_hot h5_hsv h5_jet h5_pink h5_spring h5_summer h5_winter h5_yarg h5_yellow]
-    set icolorbar(matplotlib,cmaps) [list viridis]
-    set icolorbar(matplotlib2,cmaps) [list inferno magma plasma twilight turbo]
-    set icolorbar(cubehelix,cmaps) [list ch05m151008 ch05m151010 ch05m151012 ch05m151410 ch05p151010 ch20m151010 cubehelix0 cubehelix1]
-    set icolorbar(gist,cmaps) [list gist_earth gist_heat gist_rainbow gist_yarg gist_gray gist_ncar gist_stern]
-    set icolorbar(topo,cmaps) [list tpglarf tpglhcf tpglhwf tpglpof tpglarm tpglhcm tpglhwm tpglpom]
+    set icolorbar(h5,cmaps) [list \
+				 h5_autumn \
+				 h5_bluered \
+				 h5_bone \
+				 h5_cool \
+				 h5_copper \
+				 h5_dkbluered \
+				 h5_gray \
+				 h5_green \
+				 h5_hot \
+				 h5_hsv \
+				 h5_jet \
+				 h5_pink \
+				 h5_spring \
+				 h5_summer \
+				 h5_winter \
+				 h5_yarg \
+				 h5_yellow \
+				]
+    set icolorbar(matplotlib,cmaps) [list \
+					 viridis \
+					]
+    set icolorbar(matplotlib2,cmaps) [list \
+					 inferno \
+					 magma \
+					 plasma \
+					 twilight \
+					 turbo \
+					]
+    set icolorbar(cubehelix,cmaps) [list \
+					ch05m151008 \
+					ch05m151010 \
+					ch05m151012 \
+					ch05m151410 \
+					ch05p151010 \
+					ch20m151010 \
+					cubehelix0 \
+					cubehelix1 \
+				       ]
+    set icolorbar(gist,cmaps) [list \
+				   gist_earth \
+				   gist_heat \
+				   gist_rainbow \
+				   gist_yarg \
+				   gist_gray \
+				   gist_ncar \
+				   gist_stern \
+				  ]
+    set icolorbar(topo,cmaps) [list \
+				   tpglarf \
+				   tpglhcf \
+				   tpglhwf \
+				   tpglpof \
+				   tpglarm \
+				   tpglhcm \
+				   tpglhwm \
+				   tpglpom \
+				  ]
+    set icolorbar(scm,cmaps) [list \
+				  scm_acton \
+				  scm_bam \
+				  scm_bamO \
+				  scm_bamako \
+				  scm_batlow \
+				  scm_batlowK \
+				  scm_batlowW \
+				  scm_berlin \
+				  scm_bilbao \
+				  scm_broc \
+				  scm_brocO \
+				  scm_buda \
+				  scm_bukavu \
+				  scm_cork \
+				  scm_corkO \
+				  scm_davos \
+				  scm_devon \
+				  scm_fes \
+				  scm_glasgow \
+				  scm_greyC \
+				  scm_hawaii \
+				  scm_imola \
+				  scm_lajolla \
+				  scm_lapaz \
+				  scm_lipari \
+				  scm_lisbon \
+				  scm_managua \
+				  scm_navia \
+				  scm_nuuk \
+				  scm_oleron \
+				  scm_oslo \
+				  scm_roma \
+				  scm_romaO \
+				  scm_tofino \
+				  scm_tokyo \
+				  scm_turku \
+				  scm_vanimo \
+				  scm_vik \
+				  scm_vikO \
+				 ]
     set icolorbar(user,cmaps) {}
 
     # used for Color{Button|Motion|Release}3
@@ -85,6 +197,7 @@ proc CreateColorbar {} {
     CreateColorbarExternal colorbar gist sao
     CreateColorbarExternal colorbar topo sao
     CreateColorbarExternal colorbar matplotlib2 lut
+    CreateColorbarExternal colorbar scm lut
 
     # reset current map
     colorbar map $colorbar(map)
@@ -146,6 +259,7 @@ proc CreateColorbarBase {frame} {
     CreateColorbarExternal $which gist sao
     CreateColorbarExternal $which topo sao
     CreateColorbarExternal $which matplotlib2 lut
+    CreateColorbarExternal $which scm lut
 
     # preload any user
     foreach cmap $icolorbar(user,cmaps) {
@@ -503,16 +617,26 @@ proc ColorbarKey {frame K A x y} {
     global current
     global ds9
 
-    # MacOSX and Ubuntu returns bogus values in x,y
-    # calculate our own values
-    set x [expr {[winfo pointerx $ds9(canvas)] - [winfo rootx $ds9(canvas)]}]
-    set y [expr {[winfo pointery $ds9(canvas)] - [winfo rooty $ds9(canvas)]}]
-
     global debug
     if {$debug(tcl,events)} {
 	puts stderr "ColorbarKey $frame $K $A $x $y"
     }
 
+    if {$K == {Control_R} ||
+	$K == {Control_L} ||
+	$K == {Meta_R} ||
+	$K == {Meta_L} ||
+	$K == {Alt_R} ||
+	$K == {Alt_L} ||
+	$K == {Super_R} ||
+	$K == {Super_L}} {
+	set ds9(modifier) 1
+    }
+
+    if {$ds9(modifier)} {
+	return
+    }
+
     set cb ${frame}cb
 
     switch -- $current(mode) {
@@ -537,16 +661,22 @@ proc ColorbarKey {frame K A x y} {
 proc ColorbarKeyRelease {frame K A x y} {
     global ds9
 
-    # MacOSX and Ubuntu returns bogus values in x,y
-    # calculate our own values
-    set x [expr {[winfo pointerx $ds9(canvas)] - [winfo rootx $ds9(canvas)]}]
-    set y [expr {[winfo pointery $ds9(canvas)] - [winfo rooty $ds9(canvas)]}]
-
     global debug
     if {$debug(tcl,events)} {
 	puts stderr "ColorbarKeyRelease $frame $K $A $x $y"
     }
 
+    if {$K == {Control_R} ||
+	$K == {Control_L} ||
+	$K == {Meta_R} ||
+	$K == {Meta_L} ||
+	$K == {Alt_R} ||
+	$K == {Alt_L} ||
+	$K == {Super_R} ||
+	$K == {Super_L}} {
+	set ds9(modifier) 0
+    }
+
     set cb ${frame}cb
 }
 
@@ -1088,6 +1218,8 @@ proc ColormapDialog {} {
 	-menu $mb.colormap.gist
     $mb.colormap add cascade -label [msgcat::mc {Topographic}] \
 	-menu $mb.colormap.topo
+    $mb.colormap add cascade -label [msgcat::mc {Scientific Colour Maps}] \
+	-menu $mb.colormap.scm
     $mb.colormap add cascade -label [msgcat::mc {User}] \
 	-menu $ds9(mb).color.user
 
@@ -1097,6 +1229,7 @@ proc ColormapDialog {} {
     ColormapDialogExternal cubehelix cubehelix
     ColormapDialogExternal gist gist
     ColormapDialogExternal topo topo
+    ColormapDialogExternal scm scm
     ColormapDialogExternal user user
 
     $mb.colormap add separator
@@ -1146,15 +1279,24 @@ proc ColormapDialog {} {
 proc ColormapDialogExternal {mm which} {
     global colorbar
     global icolorbar
+    global ds9
 
     set mb $icolorbar(mb)
     ThemeMenu $mb.colormap.$which
 
+    set cnt -1
     foreach cmap $icolorbar($which,cmaps) {
 	$mb.colormap.$mm add radiobutton \
 	    -label [msgcat::mc $cmap] \
 	    -variable colorbar(map) -value $cmap \
 	    -command [list ChangeColormapName $cmap]
+
+	# wrap if needed
+	incr cnt
+	if {$cnt>=$ds9(menu,size,wrap)} {
+	    set cnt 0
+	    $mb.colormap.$mm entryconfig [msgcat::mc $cmap] -columnbreak 1
+	}
     }
 }
 
@@ -1261,6 +1403,8 @@ proc UpdateColorDialog {} {
 			[msgcat::mc {Gist}] -state normal
 		    $icolorbar(mb).colormap entryconfig \
 			[msgcat::mc {Topographic}] -state normal
+		    $icolorbar(mb).colormap entryconfig \
+			[msgcat::mc {Scientific Colour Maps}] -state normal
 		    $icolorbar(mb).colormap entryconfig \
 			[msgcat::mc {User}] -state normal
 
@@ -1286,6 +1430,8 @@ proc UpdateColorDialog {} {
 			[msgcat::mc {Gist}] -state disabled
 		    $icolorbar(mb).colormap entryconfig \
 			[msgcat::mc {Topographic}] -state disabled
+		    $icolorbar(mb).colormap entryconfig \
+			[msgcat::mc {Scientific Colour Maps}] -state disabled
 		    $icolorbar(mb).colormap entryconfig \
 			[msgcat::mc {User}] -state disabled
 		}
@@ -1310,6 +1456,9 @@ proc UpdateColorDialog {} {
 		-state normal
 	    $icolorbar(mb).colormap entryconfig [msgcat::mc {Topographic}] \
 		-state normal
+	    $icolorbar(mb).colormap entryconfig \
+		[msgcat::mc {Scientific Colour Maps}] \
+		-state normal
 	    $icolorbar(mb).colormap entryconfig [msgcat::mc {User}] \
 		-state normal
 	}
