@@ -13,9 +13,9 @@ proc DS9Def {} {
     }
 
     # Must be major,minor
-    set ds9(version) {8.4}
+    set ds9(version) {8.5}
     # For display purposes only
-    set ds9(version,display) {8.4.1}
+    set ds9(version,display) {8.5}
 
     set ds9(visual) {}
     set ds9(depth) 8
@@ -36,7 +36,6 @@ proc DS9Def {} {
     }
 
     set ds9(helvetica) [font configure TkDefaultFont -family]
-    set ds9(courier) [font configure TkFixedFont -family]
     set ds9(courier) courier
     switch $ds9(wm) {
 	x11 {
@@ -132,12 +131,23 @@ proc DS9Def {} {
 
     set pds9(backup) 1
     set pds9(automarker) 1
+
+    # start XPA
     switch $ds9(wm) {
 	x11 -
 	aqua {set pds9(xpa) 1}
 	win32 {set pds9(xpa) 0}
     }
-    
+
+    # start hub if unable to find another
+    set pds9(samp,hub) 1
+
+    # start a web hub also
+    set pds9(samp,webhub) 1
+
+    # connect if samp hub is available
+    set pds9(samp) 1
+
     set pds9(prec,linear) 8
     set pds9(prec,deg) 7
     set pds9(prec,hms) 4
@@ -152,7 +162,6 @@ proc DS9Def {} {
     set pds9(bg,use) 0
     set pds9(nan) white
 
-    set pds9(samp) 1
     set pds9(confirm) 1
     set pds9(iraf) 1
     switch $ds9(wm) {
@@ -387,7 +396,7 @@ PlotDef
 PrefsDef
 PSDef
 RGBDef
-SAMPDef
+SAMPHubDef
 SAODef
 SaveDef
 SaveImageDef
@@ -517,13 +526,13 @@ if {$ds9(prefs)} {
 SetDefaultFont false
 SetDefaultTextFont false
 
-# we need to set certain variables such as debug, title, language, xpa
+# we need to set certain variables such as debug, title, language, xpa, samp
 ProcessCommandLineSecond
 
 # initialize language
 switch $pds9(language) {
     locale {
-	switch $ds9(wm) {
+    switch $ds9(wm) {
 	    x11 {
 		foreach ee {LC_MESSAGES LC_ALL LANG} {
 		    if {[info exists env($ee)]} {
@@ -603,16 +612,21 @@ InitAnalysisFile
 # Configure HTTP
 ConfigHTTP
 
-# SAMP
-if {$pds9(samp)} {
-    InitSAMP
-}
-
 # XPA
 if {$pds9(xpa)} {
     InitXPA
 }
 
+# SAMP Hub
+if {$pds9(samp,hub)} {
+    SAMPHubStart 0
+}
+
+# SAMP
+if {$pds9(samp)} {
+    SAMPConnect 0
+}
+
 # and process any command line items
 # we want to see something before any fits files are loaded
 ProcessCommandLine
