@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -259,7 +259,7 @@ proc JPEGExportDialog {varname} {
     destroy $w
 
     if {$ed2(ok)} {
-	set var $ed2(quality)
+	set var [expr int($ed2(quality))]
     }
 
     set rr $ed2(ok)
