@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -77,7 +77,7 @@ proc MarkerAnalysisStatsCB {frame id} {
 	set vvar(sky) $var(sky)
     } elseif {[info exists vvar(sky)]} {
     } else {
-	set sky $wcs(sky)
+	set vvar(sky) $wcs(sky)
     }
 
     set tt [string totitle [$frame get marker $id type]]
