@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -15,30 +15,26 @@ proc MarkerLoadDialog {} {
     set ed(ok) 0
     set ed(format) $marker(format)
     set ed(load) $marker(load)
-    set ed(frame) $current(frame)
+    set ed(color) $marker(color)
+    set ed(color,default) $marker(color,default)
 
-    set ed(system) $wcs(system)
-    set ed(sky) $wcs(sky)
-    set ed(skyformat) $wcs(skyformat)
+    set ed(frame) $current(frame)
+    set ed(system) $marker(system)
+    set ed(sky) $marker(sky)
+    set ed(skyformat) $marker(skyformat)
     AdjustCoordSystem ed system
 
-    DialogCreate $w [msgcat::mc {Load Regions}] ed(ok)
+    DialogCreate $w [msgcat::mc {Open Regions}] ed(ok)
 
-    # Param
-    set f [ttk::frame $w.param]
+    # Format
+    set f [ttk::labelframe $w.format  -text [msgcat::mc {Format}]]
 
-    ttk::label $f.formattitle -text [msgcat::mc {Format}]
     set m $f.formatbutton.menu
     ttk::menubutton $f.formatbutton -textvariable ed(format) -menu $m
-    ttk::label $f.coordtitle -text [msgcat::mc {Coordinate System}]
     set ed(cb) $f.coordbutton
     CoordMenuButton $ed(cb) ed system 1 sky skyformat {}
-    ttk::radiobutton $f.current -text [msgcat::mc {Load into Current Frame}] \
-	-variable ed(load) -value current
-    ttk::radiobutton $f.all -text [msgcat::mc {Load into All Frames}] \
-	-variable ed(load) -value all
 
-    menu $m
+    ThemeMenu $m
     $m add radiobutton -label {DS9/Funtools} -variable ed(format) -value ds9 \
 	-command UpdateMarkerLoadDialog
     $m add radiobutton -label {XML} -variable ed(format) -value xml \
@@ -54,11 +50,31 @@ proc MarkerLoadDialog {} {
     $m add radiobutton -label {X Y} -variable ed(format) -value xy \
 	-command UpdateMarkerLoadDialog
 
-    grid $f.formattitle $f.formatbutton -padx 2 -pady 2 -sticky w
-    grid $f.coordtitle $f.coordbutton -padx 2 -pady 2 -sticky w
+    grid $f.formatbutton $f.coordbutton -padx 2 -pady 2 -sticky w
+
+    # Frame
+    set f [ttk::labelframe $w.frames  -text [msgcat::mc {Frames}]]
+
+    ttk::radiobutton $f.current -text [msgcat::mc {Load into Current}] \
+	-variable ed(load) -value current
+    ttk::radiobutton $f.all -text [msgcat::mc {Load into All}] \
+	-variable ed(load) -value all
+
     grid $f.current - -padx 2 -pady 2 -sticky w
     grid $f.all - -padx 2 -pady 2 -sticky w
 
+    # Color
+    set f [ttk::labelframe $w.color  -text [msgcat::mc {Color}]]
+
+    set ed(color,chk) \
+	[ttk::checkbutton $f.default -text [msgcat::mc {Override Color}] \
+	     -variable ed(color,default) \
+	     ]
+    ColorMenuButton $f.color ed color {}
+    set ed(color,mb) $f.color
+
+    grid $f.default $f.color -padx 2 -pady 2 -sticky w
+
     # Button
     set f [ttk::frame $w.buttons]
     ttk::button $f.ok -text [msgcat::mc {OK}] -command {set ed(ok) 1} \
@@ -71,20 +87,22 @@ proc MarkerLoadDialog {} {
     # Fini
     ttk::separator $w.sep -orient horizontal
     pack $w.buttons $w.sep -side bottom -fill x
-    pack $w.param -side top -fill both -expand true
+    pack $w.format $w.frames $w.color -side top -fill both -expand true
 
     UpdateMarkerLoadDialog
 
-    DialogCenter $w 
     DialogWait $w ed(ok)
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	set marker(format) $ed(format)
 	set marker(system) $ed(system)
 	set marker(sky) $ed(sky)
 	set marker(skyformat) $ed(skyformat)
+
 	set marker(load) $ed(load)
+	set marker(color) $ed(color)
+	set marker(color,default) $ed(color,default)
     }
 
     set rr $ed(ok)
@@ -101,8 +119,41 @@ proc UpdateMarkerLoadDialog {} {
     CoordMenuEnable $mm ed system sky skyformat
 
     switch -- $ed(format) {
-	xy {$ed(cb) configure -state normal}
-	default {$ed(cb) configure -state disabled}
+	ds9 {
+	    $ed(color,chk) configure -state normal
+	    $ed(color,mb) configure -state normal
+	    $ed(cb) configure -state disabled
+	}
+	xml {
+	    $ed(color,chk) configure -state disabled
+	    $ed(color,mb) configure -state normal
+	    $ed(cb) configure -state disabled
+	}
+	ciao {
+	    $ed(color,chk) configure -state disabled
+	    $ed(color,mb) configure -state normal
+	    $ed(cb) configure -state disabled
+	}
+	saotng {
+	    $ed(color,chk) configure -state normal
+	    $ed(color,mb) configure -state normal
+	    $ed(cb) configure -state disabled
+	}
+	saoimage {
+	    $ed(color,chk) configure -state disabled
+	    $ed(color,mb) configure -state normal
+	    $ed(cb) configure -state disabled
+	}
+	pros {
+	    $ed(color,chk) configure -state disabled
+	    $ed(color,mb) configure -state normal
+	    $ed(cb) configure -state disabled
+	}
+	xy {
+	    $ed(color,chk) configure -state disabled
+	    $ed(color,mb) configure -state normal
+	    $ed(cb) configure -state normal
+	}
     }
 
     AdjustCoordSystem ed system
@@ -121,9 +172,9 @@ proc MarkerSaveDialog {title} {
     set ed(format) $marker(format)
     set ed(frame) $current(frame)
 
-    set ed(system) $wcs(system)
-    set ed(sky) $wcs(sky)
-    set ed(skyformat) $wcs(skyformat)
+    set ed(system) $marker(system)
+    set ed(sky) $marker(sky)
+    set ed(skyformat) $marker(skyformat)
     AdjustCoordSystem ed system
 
     DialogCreate $w $title ed(ok)
@@ -139,7 +190,7 @@ proc MarkerSaveDialog {title} {
 
     CoordMenuButton $ed(cb) ed system 1 sky skyformat UpdateMarkerSaveDialog
 
-    menu $m
+    ThemeMenu $m
     $m add radiobutton -label {DS9/Funtools} -variable ed(format) -value ds9 \
 	-command UpdateMarkerSaveDialog
     $m add radiobutton -label {XML} -variable ed(format) -value xml \
@@ -174,9 +225,8 @@ proc MarkerSaveDialog {title} {
 
     UpdateMarkerSaveDialog
 
-    DialogCenter $w 
     DialogWait $w ed(ok)
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	set marker(format) $ed(format)
