@@ -45,14 +45,16 @@ proc EditMainMenu {} {
 	-variable current(mode) -value footprint -command ChangeMode
     $ds9(mb).edit add radiobutton -label [msgcat::mc {Examine}] \
 	-variable current(mode) -value examine -command ChangeMode
-    $ds9(mb).edit add radiobutton -label [msgcat::mc {3D}] \
+    $ds9(mb).edit add radiobutton -label [msgcat::mc {3d}] \
 	-variable current(mode) -value 3d -command ChangeMode
+    $ds9(mb).edit add radiobutton -label [msgcat::mc {Illustrate}] \
+	-variable current(mode) -value illustrate -command ChangeMode
 
     switch $ds9(wm) {
 	x11 -
 	win32 {
 	    $ds9(mb).edit add separator
-	    $ds9(mb).edit add command -label "[msgcat::mc {Preferences}]..." \
+	    $ds9(mb).edit add command -label [msgcat::mc {Preferences}] \
 		-command PrefsDialog -accelerator "${ds9(ctrl)},"
 
 	}
@@ -109,8 +111,10 @@ proc PrefsDialogEditMenu {w} {
 	-variable pcurrent(mode) -value footprint
     $m add radiobutton -label [msgcat::mc {Examine}] \
 	-variable pcurrent(mode) -value examine
-    $m add radiobutton -label [msgcat::mc {3D}] \
+    $m add radiobutton -label [msgcat::mc {3d}] \
 	-variable pcurrent(mode) -value 3d
+    $m add radiobutton -label [msgcat::mc {Illustrate}] \
+	-variable pcurrent(mode) -value illustrate
 
     pack $f -side top -fill both -expand true
 }
@@ -137,6 +141,7 @@ proc ButtonsEditDef {} {
 	edit,footprint 1
 	edit,examine 1
 	edit,3d 1
+	edit,illustrate 1
 	edit,prefs 0
     }
 }
@@ -159,40 +164,43 @@ proc CreateButtonsEdit {} {
 
     RadioButton $ds9(buttons).edit.none \
 	[string tolower [msgcat::mc {None}]] \
-	current(mode) none ChangeMode
+	current mode none ChangeMode
     RadioButton $ds9(buttons).edit.region \
 	[string tolower [msgcat::mc {Region}]] \
-	current(mode) region ChangeMode
+	current mode region ChangeMode
     RadioButton $ds9(buttons).edit.crosshair \
 	[string tolower [msgcat::mc {Cross}]] \
-	current(mode) crosshair ChangeMode
+	current mode crosshair ChangeMode
     RadioButton $ds9(buttons).edit.colorbar \
 	[string tolower [msgcat::mc {Colorbar}]] \
-	current(mode) colorbar ChangeMode
+	current mode colorbar ChangeMode
     RadioButton $ds9(buttons).edit.pan \
 	[string tolower [msgcat::mc {Pan}]] \
-	current(mode) pan ChangeMode
+	current mode pan ChangeMode
     RadioButton $ds9(buttons).edit.zoom \
 	[string tolower [msgcat::mc {Zoom}]] \
-	current(mode) zoom ChangeMode
+	current mode zoom ChangeMode
     RadioButton $ds9(buttons).edit.rotate \
 	[string tolower [msgcat::mc {Rotate}]] \
-	current(mode) rotate ChangeMode
+	current mode rotate ChangeMode
     RadioButton $ds9(buttons).edit.crop \
 	[string tolower [msgcat::mc {Crop}]] \
-	current(mode) crop ChangeMode
+	current mode crop ChangeMode
     RadioButton $ds9(buttons).edit.catalog \
 	[string tolower [msgcat::mc {Cat}]] \
-	current(mode) catalog ChangeMode
+	current mode catalog ChangeMode
     RadioButton $ds9(buttons).edit.footprint \
         [string tolower [msgcat::mc {FP}]] \
-        current(mode) footprint ChangeMode
+        current mode footprint ChangeMode
     RadioButton $ds9(buttons).edit.examine \
 	[string tolower [msgcat::mc {Exam}]] \
-	current(mode) examine ChangeMode
+	current mode examine ChangeMode
     RadioButton $ds9(buttons).edit.3d \
-	[string tolower [msgcat::mc {3D}]] \
-	current(mode) 3d ChangeMode
+	[string tolower [msgcat::mc {3d}]] \
+	current mode 3d ChangeMode
+    RadioButton $ds9(buttons).edit.illustrate \
+	[string tolower [msgcat::mc {Illustrate}]] \
+	current mode illustrate ChangeMode
 
     ButtonButton $ds9(buttons).edit.prefs \
 	[string tolower [msgcat::mc {Preferences}]] PrefsDialog
@@ -214,6 +222,7 @@ proc CreateButtonsEdit {} {
         $ds9(buttons).edit.footprint pbuttons(edit,footprint)                   
         $ds9(buttons).edit.examine pbuttons(edit,examine)
         $ds9(buttons).edit.3d pbuttons(edit,3d)
+        $ds9(buttons).edit.illustrate pbuttons(edit,illustrate)
         $ds9(buttons).edit.prefs pbuttons(edit,prefs)
     "
 }
@@ -228,42 +237,62 @@ proc PrefsDialogButtonbarEdit {f} {
     set m $f.menu
     ThemeMenu $m
     $m add checkbutton -label [msgcat::mc {Undo}] \
-	-variable pbuttons(edit,undo) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,undo) \
+	-command {UpdateButtons buttons(edit)}
     $m add separator
     $m add checkbutton -label [msgcat::mc {Cut}] \
-	-variable pbuttons(edit,cut) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,cut) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Copy}] \
-	-variable pbuttons(edit,copy) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,copy) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Paste}] \
-	-variable pbuttons(edit,paste) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,paste) \
+	-command {UpdateButtons buttons(edit)}
     $m add separator
     $m add checkbutton -label [msgcat::mc {None}] \
-	-variable pbuttons(edit,none) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,none) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Region}] \
-	-variable pbuttons(edit,region) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,region) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Crosshair}] \
-	-variable pbuttons(edit,crosshair) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,crosshair) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Colorbar}] \
-	-variable pbuttons(edit,colorbar) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,colorbar) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Pan}] \
-	-variable pbuttons(edit,pan) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,pan) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Zoom}] \
-	-variable pbuttons(edit,zoom) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,zoom) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Rotate}] \
-	-variable pbuttons(edit,rotate) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,rotate) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Crop}] \
-	-variable pbuttons(edit,crop) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,crop) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Catalog}] \
-	-variable pbuttons(edit,catalog) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,catalog) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Footprint}] \
-	-variable pbuttons(edit,footprint) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,footprint) \
+	-command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Examine}] \
-	-variable pbuttons(edit,examine) -command {UpdateButtons buttons(edit)}
-    $m add checkbutton -label [msgcat::mc {3D}] \
-	-variable pbuttons(edit,3d) -command {UpdateButtons buttons(3d)}
+	-variable pbuttons(edit,examine) \
+	-command {UpdateButtons buttons(edit)}
+    $m add checkbutton -label [msgcat::mc {3d}] \
+	-variable pbuttons(edit,3d) \
+	-command {UpdateButtons buttons(3d)}
+    $m add checkbutton -label [msgcat::mc {Illustrate}] \
+	-variable pbuttons(edit,illustrate) \
+	-command {UpdateButtons buttons(illustrate)}
     $m add separator
     $m add checkbutton -label [msgcat::mc {Preferences}] \
-	-variable pbuttons(edit,prefs) -command {UpdateButtons buttons(edit)}
+	-variable pbuttons(edit,prefs) \
+	-command {UpdateButtons buttons(edit)}
 }
 
 # Support
@@ -271,7 +300,6 @@ proc PrefsDialogButtonbarEdit {f} {
 proc UpdateEditMenu {} {
     global ds9
     global current
-    global marker
 
     global debug
     if {$debug(tcl,update)} {
@@ -281,6 +309,8 @@ proc UpdateEditMenu {} {
     switch -- $current(mode) {
 	pointer -
 	region {
+	    global marker
+
 	    if {$current(frame) != {}} {
 		set l [$current(frame) has marker undo]
 		if {$l != {}} {
@@ -333,6 +363,34 @@ proc UpdateEditMenu {} {
 	footprint -
 	examine -
 	iexam -
-	3d {$ds9(mb).edit entryconfig [msgcat::mc {Undo}] -state disabled}
+	3d {
+	    $ds9(mb).edit entryconfig [msgcat::mc {Undo}] -state disabled
+	    $ds9(mb).edit entryconfig [msgcat::mc {Cut}] -state disabled
+	    $ds9(mb).edit entryconfig [msgcat::mc {Copy}] -state disabled
+	    $ds9(mb).edit entryconfig [msgcat::mc {Paste}] -state disabled
+	}
+	illustrate {
+	    global iillustrate
+
+	    if {$iillustrate(undo) != {}} {
+		$ds9(mb).edit entryconfig [msgcat::mc {Undo}] -state normal
+	    } else {
+		$ds9(mb).edit entryconfig [msgcat::mc {Undo}] -state disabled
+	    }
+
+	    if {$iillustrate(selection) != {}} {
+		$ds9(mb).edit entryconfig [msgcat::mc {Cut}] -state normal
+		$ds9(mb).edit entryconfig [msgcat::mc {Copy}] -state normal
+	    } else {
+		$ds9(mb).edit entryconfig [msgcat::mc {Cut}] -state disabled
+		$ds9(mb).edit entryconfig [msgcat::mc {Copy}] -state disabled
+	    }
+
+	    if {$iillustrate(clipboard) != {} } {
+		$ds9(mb).edit entryconfig [msgcat::mc {Paste}] -state normal
+	    } else {
+		$ds9(mb).edit entryconfig [msgcat::mc {Paste}] -state disabled
+	    }
+	}
     }
 }
