@@ -36,6 +36,8 @@ proc FrameMainMenu {} {
 	-variable current(display) -value tile -command DisplayMode
     $ds9(mb).frame add radiobutton -label [msgcat::mc {Blink Frames}] \
 	-variable current(display) -value blink -command DisplayMode
+    $ds9(mb).frame add radiobutton -label [msgcat::mc {Fade Frames}] \
+	-variable current(display) -value fade -command DisplayMode
     $ds9(mb).frame add separator
     $ds9(mb).frame add cascade -label [msgcat::mc {Match}] \
 	-menu $ds9(mb).frame.match
@@ -58,11 +60,11 @@ proc FrameMainMenu {} {
     $ds9(mb).frame add command -label [msgcat::mc {Last Frame}] \
 	-command LastFrame
     $ds9(mb).frame add separator
-    $ds9(mb).frame add command -label "[msgcat::mc {Cube}]..." \
+    $ds9(mb).frame add command -label [msgcat::mc {Cube}] \
 	-command CubeDialog
-    $ds9(mb).frame add command -label "[msgcat::mc {RGB}]..." \
+    $ds9(mb).frame add command -label [msgcat::mc {RGB}] \
 	-command RGBDialog
-    $ds9(mb).frame add command -label "[msgcat::mc {3D}]..." \
+    $ds9(mb).frame add command -label [msgcat::mc {3d}] \
 	-command 3DDialog
     $ds9(mb).frame add separator
     $ds9(mb).frame add cascade -label [msgcat::mc {Frame Parameters}] \
@@ -92,7 +94,7 @@ proc FrameMainMenu {} {
 	-command MatchBlockCurrent
     $ds9(mb).frame.match add command -label [msgcat::mc {Smooth}] \
 	-command MatchSmoothCurrent
-    $ds9(mb).frame.match add command -label [msgcat::mc {3D View}] \
+    $ds9(mb).frame.match add command -label [msgcat::mc {3d}] \
 	-command Match3DCurrent
 
     ThemeMenu $ds9(mb).frame.match.frame
@@ -165,7 +167,7 @@ proc FrameMainMenu {} {
 	-variable block(lock) -command {LockBlockCurrent}
     $ds9(mb).frame.lock add checkbutton -label [msgcat::mc {Smooth}] \
 	-variable smooth(lock) -command {LockSmoothCurrent}
-    $ds9(mb).frame.lock add checkbutton -label [msgcat::mc {3D View}] \
+    $ds9(mb).frame.lock add checkbutton -label [msgcat::mc {3d}] \
 	-variable threed(lock) -command {Lock3DCurrent}
 
     ThemeMenu $ds9(mb).frame.lock.frame
@@ -259,6 +261,8 @@ proc FrameMainMenu {} {
 	-menu $ds9(mb).frame.params.tile
     $ds9(mb).frame.params add cascade -label [msgcat::mc {Blink Interval}] \
 	-menu $ds9(mb).frame.params.blink
+    $ds9(mb).frame.params add cascade -label [msgcat::mc {Fade Interval}] \
+	-menu $ds9(mb).frame.params.fade
     $ds9(mb).frame.params add command -label [msgcat::mc {Display Size}] \
 	-command DisplayDefaultDialog
 
@@ -271,23 +275,20 @@ proc FrameMainMenu {} {
 	-variable tile(mode) -value row -command DisplayMode
     $ds9(mb).frame.params.tile add separator
     $ds9(mb).frame.params.tile add command \
-	-label "[msgcat::mc {Tile Parameters}]..." -command TileDialog
+	-label [msgcat::mc {Tile Parameters}] -command TileDialog
 
     ThemeMenu $ds9(mb).frame.params.blink
     $ds9(mb).frame.params.blink add radiobutton \
-	-label "1/16 [msgcat::mc {Seconds}]" \
-	-variable blink(interval) -value 6
-    $ds9(mb).frame.params.blink add radiobutton \
-	-label "1/8 [msgcat::mc {Seconds}]" \
+	-label ".125 [msgcat::mc {Seconds}]" \
 	-variable blink(interval) -value 125
     $ds9(mb).frame.params.blink add radiobutton \
-	-label "1/4 [msgcat::mc {Seconds}]" \
+	-label ".25 [msgcat::mc {Seconds}]" \
 	-variable blink(interval) -value 250
     $ds9(mb).frame.params.blink add radiobutton \
-	-label "1/2 [msgcat::mc {Seconds}]" \
+	-label ".5 [msgcat::mc {Seconds}]" \
 	-variable blink(interval) -value 500
     $ds9(mb).frame.params.blink add radiobutton \
-	-label "1 [msgcat::mc {Seconds}]" \
+	-label "1 [msgcat::mc {Second}]" \
 	-variable blink(interval) -value 1000
     $ds9(mb).frame.params.blink add radiobutton \
 	-label "2  [msgcat::mc {Seconds}]" \
@@ -301,6 +302,21 @@ proc FrameMainMenu {} {
     $ds9(mb).frame.params.blink add radiobutton \
 	-label "16 [msgcat::mc {Seconds}]" \
 	-variable blink(interval) -value 16000
+
+    # times are doubled
+    ThemeMenu $ds9(mb).frame.params.fade
+    $ds9(mb).frame.params.fade add radiobutton \
+	-label "1  [msgcat::mc {Second}]" \
+	-variable fade(interval) -value 1000
+    $ds9(mb).frame.params.fade add radiobutton \
+	-label "2  [msgcat::mc {Seconds}]" \
+	-variable fade(interval) -value 2000
+    $ds9(mb).frame.params.fade add radiobutton \
+	-label "4 [msgcat::mc {Seconds}]" \
+	-variable fade(interval) -value 4000
+    $ds9(mb).frame.params.fade add radiobutton \
+	-label "8 [msgcat::mc {Seconds}]" \
+	-variable fade(interval) -value 8000
 }
 
 proc PrefsDialogFrameMenu {w} {
@@ -319,6 +335,8 @@ proc PrefsDialogFrameMenu {w} {
 	-variable pcurrent(display) -value tile
     $m add radiobutton -label [msgcat::mc {Blink Frames}] \
 	-variable pcurrent(display) -value blink
+    $m add radiobutton -label [msgcat::mc {Fade Frames}] \
+	-variable pcurrent(display) -value fade
     $m add separator
     $m add cascade -label [msgcat::mc {Frame Parameters}] \
 	-menu $m.params
@@ -328,6 +346,8 @@ proc PrefsDialogFrameMenu {w} {
 	-menu $m.params.tile
     $m.params add cascade -label [msgcat::mc {Blink Interval}] \
 	-menu $m.params.blink
+    $m.params add cascade -label [msgcat::mc {Fade Interval}] \
+	-menu $m.params.fade
 
     ThemeMenu $m.params.tile
     $m.params.tile add radiobutton -label [msgcat::mc {Grid}] \
@@ -344,7 +364,7 @@ proc PrefsDialogFrameMenu {w} {
 	-variable pblink(interval) -value 250
     $m.params.blink add radiobutton -label ".5 [msgcat::mc {Seconds}]" \
 	-variable pblink(interval) -value 500
-    $m.params.blink add radiobutton -label "1 [msgcat::mc {Seconds}]" \
+    $m.params.blink add radiobutton -label "1 [msgcat::mc {Second}]" \
 	-variable pblink(interval) -value 1000
     $m.params.blink add radiobutton -label "2  [msgcat::mc {Seconds}]" \
 	-variable pblink(interval) -value 2000
@@ -352,6 +372,19 @@ proc PrefsDialogFrameMenu {w} {
 	-variable pblink(interval) -value 4000
     $m.params.blink add radiobutton -label "8 [msgcat::mc {Seconds}]" \
 	-variable pblink(interval) -value 8000
+    $m.params.blink add radiobutton -label "16 [msgcat::mc {Seconds}]" \
+	-variable pblink(interval) -value 16000
+
+    # times are doubled
+    ThemeMenu $m.params.fade
+    $m.params.fade add radiobutton -label "1  [msgcat::mc {Second}]" \
+	-variable pfade(interval) -value 1000
+    $m.params.fade add radiobutton -label "2  [msgcat::mc {Seconds}]" \
+	-variable pfade(interval) -value 2000
+    $m.params.fade add radiobutton -label "4 [msgcat::mc {Seconds}]" \
+	-variable pfade(interval) -value 4000
+    $m.params.fade add radiobutton -label "8 [msgcat::mc {Seconds}]" \
+	-variable pfade(interval) -value 8000
 
     pack $f -side top -fill both -expand true
 }
@@ -373,6 +406,7 @@ proc ButtonsFrameDef {} {
 	frame,single 1
 	frame,tile 1
 	frame,blink 1
+	frame,fade 1
 
 	frame,match,bin 0
 	frame,match,axes 0
@@ -461,7 +495,7 @@ proc CreateButtonsFrame {} {
     ButtonButton $ds9(buttons).frame.newrgb \
 	[string tolower [msgcat::mc {RGB}]] CreateRGBFrame
     ButtonButton $ds9(buttons).frame.new3d \
-	[string tolower [msgcat::mc {3D}]] Create3DFrame
+	[string tolower [msgcat::mc {3d}]] Create3DFrame
 
     ButtonButton $ds9(buttons).frame.delete \
 	[string tolower [msgcat::mc {Delete}]] DeleteCurrentFrame
@@ -477,13 +511,16 @@ proc CreateButtonsFrame {} {
 
     RadioButton $ds9(buttons).frame.single \
 	[string tolower [msgcat::mc {Single}]] \
-	current(display) single DisplayMode
+	current display single DisplayMode
     RadioButton $ds9(buttons).frame.tile \
 	[string tolower [msgcat::mc {Tile}]] \
-	current(display) tile DisplayMode
+	current display tile DisplayMode
     RadioButton $ds9(buttons).frame.blink \
 	[string tolower [msgcat::mc {Blink}]] \
-	current(display) blink DisplayMode
+	current display blink DisplayMode
+    RadioButton $ds9(buttons).frame.fade \
+	[string tolower [msgcat::mc {Fade}]] \
+	current display fade DisplayMode
 
     ButtonButton $ds9(buttons).frame.matchbin \
 	[string tolower [msgcat::mc {Match Bin}]] MatchBinCurrent
@@ -555,87 +592,88 @@ proc CreateButtonsFrame {} {
 	{MatchCubeCurrent image}
 
     CheckButton $ds9(buttons).frame.lockbin \
-	[string tolower [msgcat::mc {Lock Bin}]] bin(lock) LockBinCurrent
+	[string tolower [msgcat::mc {Lock Bin}]] bin lock LockBinCurrent
     CheckButton $ds9(buttons).frame.lockaxes \
 	[string tolower [msgcat::mc {Lock Axes}]] \
-	cube(lock,axes) LockAxesCurrent
+	cube lock,axes LockAxesCurrent
     CheckButton $ds9(buttons).frame.lockscale \
-	[string tolower [msgcat::mc {Lock Scale}]] scale(lock) LockScaleCurrent
+	[string tolower [msgcat::mc {Lock Scale}]] scale lock LockScaleCurrent
     CheckButton $ds9(buttons).frame.lockscalelimits \
 	[string tolower [msgcat::mc {Lock Limits}]] \
-	scale(lock,limits) LockScaleLimitsCurrent
+	scale lock,limits LockScaleLimitsCurrent
     CheckButton $ds9(buttons).frame.lockcolor \
-	[string tolower [msgcat::mc {Lock Color}]] color(lock) LockColorCurrent
+	[string tolower [msgcat::mc {Lock Color}]] \
+	colorbar lock LockColorCurrent
     CheckButton $ds9(buttons).frame.locksmooth \
 	[string tolower [msgcat::mc {Lock Smooth}]] \
-	smooth(lock) LockSmoothCurrent
+	smooth lock LockSmoothCurrent
 
     RadioButton $ds9(buttons).frame.lockframenone \
 	[string tolower [msgcat::mc {Lock Frame None}]] \
-	panzoom(lock) none LockFrameCurrent
+	panzoom lock none LockFrameCurrent
     RadioButton $ds9(buttons).frame.lockframewcs \
 	[string tolower [msgcat::mc {Lock Frame WCS}]] \
-	panzoom(lock) wcs LockFrameCurrent
+	panzoom lock wcs LockFrameCurrent
     RadioButton $ds9(buttons).frame.lockframeimage \
 	[string tolower [msgcat::mc {Lock Frame Image}]] \
-	panzoom(lock) image LockFrameCurrent
+	panzoom lock image LockFrameCurrent
     RadioButton $ds9(buttons).frame.lockframephysical \
 	[string tolower [msgcat::mc {Lock Frame Physical}]] \
-	panzoom(lock) physical LockFrameCurrent
+	panzoom lock physical LockFrameCurrent
     RadioButton $ds9(buttons).frame.lockframedetector \
 	[string tolower [msgcat::mc {Lock Frame Detector}]] \
-	panzoom(lock) detector LockFrameCurrent
+	panzoom lock detector LockFrameCurrent
     RadioButton $ds9(buttons).frame.lockframeamplifier \
 	[string tolower [msgcat::mc {Lock Frame Amplifier}]] \
-	panzoom(lock) amplifier LockFrameCurrent
+	panzoom lock amplifier LockFrameCurrent
 
     RadioButton $ds9(buttons).frame.lockcrosshairnone \
 	[string tolower [msgcat::mc {Lock Crosshair None}]] \
-	crosshair(lock) none LockCrosshairCurrent
+	crosshair lock none LockCrosshairCurrent
     RadioButton $ds9(buttons).frame.lockcrosshairwcs \
 	[string tolower [msgcat::mc {Lock Crosshair WCS}]] \
-	crosshair(lock) wcs LockCrosshairCurrent
+	crosshair lock wcs LockCrosshairCurrent
     RadioButton $ds9(buttons).frame.lockcrosshairimage \
 	[string tolower [msgcat::mc {Lock Crosshair Image}]] \
-	crosshair(lock) image LockCrosshairCurrent
+	crosshair lock image LockCrosshairCurrent
     RadioButton $ds9(buttons).frame.lockcrosshairphysical \
 	[string tolower [msgcat::mc {Lock Crosshair Physical}]] \
-	crosshair(lock) physical LockCrosshairCurrent
+	crosshair lock physical LockCrosshairCurrent
     RadioButton $ds9(buttons).frame.lockcrosshairdetector \
 	[string tolower [msgcat::mc {Lock Crosshair Detector}]] \
-	crosshair(lock) detector LockCrosshairCurrent
+	crosshair lock detector LockCrosshairCurrent
     RadioButton $ds9(buttons).frame.lockcrosshairamplifier \
 	[string tolower [msgcat::mc {Lock Crosshair Amplifier}]] \
-	crosshair(lock) amplifier LockCrosshairCurrent
+	crosshair lock amplifier LockCrosshairCurrent
 
     RadioButton $ds9(buttons).frame.lockcropnone \
 	[string tolower [msgcat::mc {Lock Crop None}]] \
-	crop(lock) none LockCropCurrent
+	crop lock none LockCropCurrent
     RadioButton $ds9(buttons).frame.lockcropwcs \
 	[string tolower [msgcat::mc {Lock Crop WCS}]] \
-	crop(lock) wcs LockCropCurrent
+	crop lock wcs LockCropCurrent
     RadioButton $ds9(buttons).frame.lockcropimage \
 	[string tolower [msgcat::mc {Lock Crop Image}]] \
-	crop(lock) image LockCropCurrent
+	crop lock image LockCropCurrent
     RadioButton $ds9(buttons).frame.lockcropphysical \
 	[string tolower [msgcat::mc {Lock Crop Physical}]] \
-	crop(lock) physical LockCropCurrent
+	crop lock physical LockCropCurrent
     RadioButton $ds9(buttons).frame.lockcropdetector \
 	[string tolower [msgcat::mc {Lock Crop Detector}]] \
-	crop(lock) detector LockCropCurrent
+	crop lock detector LockCropCurrent
     RadioButton $ds9(buttons).frame.lockcropamplifier \
 	[string tolower [msgcat::mc {Lock Crop Amplifier}]] \
-	crop(lock) amplifier LockCropCurrent
+	crop lock amplifier LockCropCurrent
 
     RadioButton $ds9(buttons).frame.lockcubenone \
 	[string tolower [msgcat::mc {Lock Slice None}]] \
-	cube(lock) none LockCubeCurrent
+	cube lock none LockCubeCurrent
     RadioButton $ds9(buttons).frame.lockcubewcs \
 	[string tolower [msgcat::mc {Lock Slice WCS}]] \
-	cube(lock) wcs LockCubeCurrent
+	cube lock wcs LockCubeCurrent
     RadioButton $ds9(buttons).frame.lockcubeimage \
 	[string tolower [msgcat::mc {Lock Slice Image}]] \
-	cube(lock) image LockCubeCurrent
+	cube lock image LockCubeCurrent
 
     ButtonButton $ds9(buttons).frame.movefirst \
 	[string tolower [msgcat::mc {Move First}]] MoveFirstFrame
@@ -656,11 +694,11 @@ proc CreateButtonsFrame {} {
 	[string tolower [msgcat::mc {Last}]] LastFrame
 
     ButtonButton $ds9(buttons).frame.cube \
-	[string tolower "[msgcat::mc {Cube}]..."] CubeDialog
+	[string tolower [msgcat::mc {Cube}]] CubeDialog
     ButtonButton $ds9(buttons).frame.rgb \
-	[string tolower "[msgcat::mc {RGB}]..."] RGBDialog
+	[string tolower [msgcat::mc {RGB}]] RGBDialog
     ButtonButton $ds9(buttons).frame.3d \
-	[string tolower "[msgcat::mc {3D}]..."] 3DDialog
+	[string tolower [msgcat::mc {3d}]] 3DDialog
 
     ButtonButton $ds9(buttons).frame.size \
 	[string tolower [msgcat::mc {Size}]] DisplayDefaultDialog
@@ -677,6 +715,7 @@ proc CreateButtonsFrame {} {
         $ds9(buttons).frame.single pbuttons(frame,single)
         $ds9(buttons).frame.tile pbuttons(frame,tile)
         $ds9(buttons).frame.blink pbuttons(frame,blink)
+        $ds9(buttons).frame.fade pbuttons(frame,fade)
 
         $ds9(buttons).frame.matchbin pbuttons(frame,match,bin)
         $ds9(buttons).frame.matchaxes pbuttons(frame,match,axes)
@@ -787,6 +826,8 @@ proc PrefsDialogButtonbarFrame {f} {
 	-variable pbuttons(frame,tile) -command {UpdateButtons buttons(frame)}
     $m add checkbutton -label [msgcat::mc {Blink Frames}] \
 	-variable pbuttons(frame,blink) -command {UpdateButtons buttons(frame)}
+    $m add checkbutton -label [msgcat::mc {Fade Frames}] \
+	-variable pbuttons(frame,fade) -command {UpdateButtons buttons(frame)}
     $m add separator
     $m add cascade -label [msgcat::mc {Match}] -menu $m.match
     $m add cascade -label [msgcat::mc {Lock}] -menu $m.lock
@@ -802,11 +843,11 @@ proc PrefsDialogButtonbarFrame {f} {
     $m add checkbutton -label [msgcat::mc {Last Frame}] \
 	-variable pbuttons(frame,last) -command {UpdateButtons buttons(frame)}
     $m add separator
-    $m add checkbutton -label "[msgcat::mc {Cube}]..." \
+    $m add checkbutton -label [msgcat::mc {Cube}] \
 	-variable pbuttons(frame,cube) -command {UpdateButtons buttons(frame)}
-    $m add checkbutton -label "[msgcat::mc {RGB}]..." \
+    $m add checkbutton -label [msgcat::mc {RGB}] \
 	-variable pbuttons(frame,rgb) -command {UpdateButtons buttons(frame)}
-    $m add checkbutton -label "[msgcat::mc {3D}]..." \
+    $m add checkbutton -label [msgcat::mc {3d}] \
 	-variable pbuttons(frame,3d) -command {UpdateButtons buttons(frame)}
     $m add separator
     $m add cascade -label [msgcat::mc {Frame Parameters}] -menu $m.params
@@ -1045,9 +1086,6 @@ proc UpdateFrameMenu {} {
 	puts stderr "UpdateFrameMenu"
     }
 
-    $ds9(mb).frame entryconfig [msgcat::mc {New Frame RGB}] -state normal
-    $ds9(buttons).frame.newrgb configure -state normal
-
     if {[llength $ds9(active)] > 0} {
 	$ds9(mb).frame entryconfig [msgcat::mc {Delete Frame}] -state normal
 	$ds9(mb).frame entryconfig [msgcat::mc {Delete All Frames}] -state normal
@@ -1056,9 +1094,10 @@ proc UpdateFrameMenu {} {
 	$ds9(mb).frame entryconfig [msgcat::mc {Reset Frame}] -state normal
 	$ds9(mb).frame entryconfig [msgcat::mc {Refresh Frame}] -state normal
 
-	$ds9(mb).frame entryconfig [msgcat::mc {Single Frame}] -state normal
-	$ds9(mb).frame entryconfig [msgcat::mc {Tile Frames}] -state normal
-	$ds9(mb).frame entryconfig [msgcat::mc {Blink Frames}] -state normal
+#	$ds9(mb).frame entryconfig [msgcat::mc {Single Frame}] -state normal
+#	$ds9(mb).frame entryconfig [msgcat::mc {Tile Frames}] -state normal
+#	$ds9(mb).frame entryconfig [msgcat::mc {Blink Frames}] -state normal
+#	$ds9(mb).frame entryconfig [msgcat::mc {Fade Frames}] -state normal
 
 	$ds9(mb).frame entryconfig [msgcat::mc {Match}] -state normal
 	$ds9(mb).frame entryconfig [msgcat::mc {Lock}] -state normal
@@ -1077,9 +1116,10 @@ proc UpdateFrameMenu {} {
 	$ds9(buttons).frame.reset configure -state normal
 	$ds9(buttons).frame.refresh configure -state normal
 
-	$ds9(buttons).frame.single configure -state normal
-	$ds9(buttons).frame.tile configure -state normal
-	$ds9(buttons).frame.blink configure -state normal
+#	$ds9(buttons).frame.single configure -state normal
+#	$ds9(buttons).frame.tile configure -state normal
+#	$ds9(buttons).frame.blink configure -state normal
+#	$ds9(buttons).frame.fade configure -state normal
 
 	$ds9(buttons).frame.movefirst configure -state normal
 	$ds9(buttons).frame.moveprev configure -state normal
@@ -1098,9 +1138,10 @@ proc UpdateFrameMenu {} {
 	$ds9(mb).frame entryconfig [msgcat::mc {Reset Frame}] -state disabled
 	$ds9(mb).frame entryconfig [msgcat::mc {Refresh Frame}] -state disabled
 
-	$ds9(mb).frame entryconfig [msgcat::mc {Single Frame}] -state disabled
-	$ds9(mb).frame entryconfig [msgcat::mc {Tile Frames}] -state disabled
-	$ds9(mb).frame entryconfig [msgcat::mc {Blink Frames}] -state disabled
+#	$ds9(mb).frame entryconfig [msgcat::mc {Single Frame}] -state disabled
+#	$ds9(mb).frame entryconfig [msgcat::mc {Tile Frames}] -state disabled
+#	$ds9(mb).frame entryconfig [msgcat::mc {Blink Frames}] -state disabled
+#	$ds9(mb).frame entryconfig [msgcat::mc {Fade Frames}] -state disabled
 
 	$ds9(mb).frame entryconfig [msgcat::mc {Match}] -state disabled
 	$ds9(mb).frame entryconfig [msgcat::mc {Lock}] -state disabled
@@ -1119,9 +1160,10 @@ proc UpdateFrameMenu {} {
 	$ds9(buttons).frame.reset configure -state disabled
 	$ds9(buttons).frame.refresh configure -state disabled
 
-	$ds9(buttons).frame.single configure -state disabled
-	$ds9(buttons).frame.tile configure -state disabled
-	$ds9(buttons).frame.blink configure -state disabled
+#	$ds9(buttons).frame.single configure -state disabled
+#	$ds9(buttons).frame.tile configure -state disabled
+#	$ds9(buttons).frame.blink configure -state disabled
+#	$ds9(buttons).frame.fade configure -state disabled
 
 	$ds9(buttons).frame.movefirst configure -state disabled
 	$ds9(buttons).frame.moveprev configure -state disabled
@@ -1135,42 +1177,42 @@ proc UpdateFrameMenu {} {
     }
 
     if {$current(frame) != {}} {
-	$ds9(mb).frame entryconfig "[msgcat::mc {Cube}]..." \
+	$ds9(mb).frame entryconfig [msgcat::mc {Cube}] \
 	    -state normal
 	$ds9(buttons).frame.cube configure -state normal
 
 	switch -- [$current(frame) get type] {
 	    base {
-		$ds9(mb).frame entryconfig "[msgcat::mc {RGB}]..." \
+		$ds9(mb).frame entryconfig [msgcat::mc {RGB}] \
 		    -state disabled
-		$ds9(mb).frame entryconfig "[msgcat::mc {3D}]..." \
+		$ds9(mb).frame entryconfig [msgcat::mc {3d}] \
 		    -state normal
 		$ds9(buttons).frame.rgb configure -state disabled
 		$ds9(buttons).frame.3d configure -state normal
 	    }
 	    rgb {
-		$ds9(mb).frame entryconfig "[msgcat::mc {RGB}]..." \
+		$ds9(mb).frame entryconfig [msgcat::mc {RGB}] \
 		    -state normal
-		$ds9(mb).frame entryconfig "[msgcat::mc {3D}]..." \
+		$ds9(mb).frame entryconfig [msgcat::mc {3d}] \
 		    -state disabled
 		$ds9(buttons).frame.rgb configure -state normal
 		$ds9(buttons).frame.3d configure -state disabled
 	    }
 	    3d {
-		$ds9(mb).frame entryconfig "[msgcat::mc {RGB}]..." \
+		$ds9(mb).frame entryconfig [msgcat::mc {RGB}] \
 		    -state disabled
-		$ds9(mb).frame entryconfig "[msgcat::mc {3D}]..."  \
+		$ds9(mb).frame entryconfig [msgcat::mc {3d}]  \
 		    -state normal
 		$ds9(buttons).frame.rgb configure -state disabled
 		$ds9(buttons).frame.3d configure -state normal
 	    }
 	}
     } else {
-	$ds9(mb).frame entryconfig "[msgcat::mc {Cube}]..." \
+	$ds9(mb).frame entryconfig [msgcat::mc {Cube}] \
 	    -state disabled
-	$ds9(mb).frame entryconfig "[msgcat::mc {RGB}]..." \
+	$ds9(mb).frame entryconfig [msgcat::mc {RGB}] \
 	    -state disabled
-	$ds9(mb).frame entryconfig "[msgcat::mc {3D}]..." \
+	$ds9(mb).frame entryconfig [msgcat::mc {3d}] \
 	    -state disabled
 	$ds9(buttons).frame.cube configure -state disabled
 	$ds9(buttons).frame.rgb configure -state disabled
