@@ -739,20 +739,20 @@ proc Sex2D {str} {
     return [expr $sign * (abs($degree)+($min/60.)+($sec/(60.*60.)))]
 }
 
-proc WarpCursor {which x y} {
+proc WarpCursor {canvas which x y} {
     global ds9
 
     $which warp $x $y
-    # major kludge: macos warp does not generate motion event
+    # major kludge: warp does not generate motion event
     switch $ds9(wm) {
-	x11 -
-	win32 {}
+	x11 {}
 	aqua {
 	    set foo [$which query cursor]
 	    set xx [expr [lindex $foo 0]+$x]
 	    set yy [expr [lindex $foo 1]+$y]
-	    event generate $ds9(canvas) <Motion> -x $xx -y $yy
+	    event generate $canvas <Motion> -x $xx -y $yy
 	}
+	win32 {}
     }
 }
 
@@ -760,16 +760,16 @@ proc WarpToCursor {which x y} {
     global ds9
 
     $which warp to $x $y
-    # major kludge: macos warp does not generate motion event
+    # major kludge: warp does not generate motion event
     switch $ds9(wm) {
-	x11 -
-	win32 {}
+	x11 {}
 	aqua {
 	    set foo [$which query cursor]
 	    set xx [lindex $foo 0]
 	    set yy [lindex $foo 1]
 	    event generate $ds9(canvas) <Motion> -x $xx -y $yy
 	}
+	win32 {}
     }
 }
 
@@ -848,13 +848,13 @@ proc AboutBoxDefault {} {
 
     # Param
     set f [ttk::frame $w.param]
-    canvas $f.c -background white -height 300 -width 500
+    canvas $f.c -background white -height 400 -width 500
     pack $f.c -fill both -expand true
     
     set ed(sun) [image create photo -file $ds9(root)/doc/sun.png]
     
     $f.c create image 0 0 -image $ed(sun) -anchor nw
-    $f.c create text 120 22 -text $help(about) -anchor nw -width 350
+    $f.c create text 120 22 -text $help(about) -anchor nw -width 400
 
     # Buttons
     set f [ttk::frame $w.buttons]
@@ -882,9 +882,15 @@ proc QuitDS9 {} {
     # shutdown SAMP
     global samp
     if {[info exists samp]} {
-	catch {SAMPDisconnect}
+	catch {SAMPDisconnect 0}
     }
 
+    # shutdown SAMPHUB
+    global samphub
+    if {[info exists samphub]} {
+	catch {SAMPHubStop 0}
+    }
+    
     # close IIS ports
     catch {IISClose}
 
@@ -1596,13 +1602,14 @@ proc ProcessCursorCmd {varname iname} {
 
 proc CursorCmd {x y} {
     global current
+    global ds9
 
     if {$current(frame) == {}} {
 	return
     }
 
     switch -- $current(mode) {
-	none {WarpCursor $current(frame) $x $y}
+	none {WarpCursor $ds9(canvas) $current(frame) $x $y}
 	pointer -
 	region -
 	catalog -
