@@ -68,14 +68,10 @@ namespace eval xmlrpc {
     namespace	export call buildRequest marshall unmarshall assoc
     namespace	export serve
 
-    variable	READSIZE 4096;		# read size
-
+    variable	READSIZE 4096;
     variable	WS	"\[ |\n|\t\|\r]";	# WhiteSpace
     variable	W	"\[^ |\n|\t\]";		# a word with no spaces
     variable	DIGIT	"\[0-9\]";		# Digit
-
-    variable	response	"";		# response to return
-    variable	acceptfd	"";		# socket to listen on
     variable	DEBUG		0;		# debug
 }
 
@@ -83,17 +79,13 @@ namespace eval xmlrpc {
 # and start listening on it
 #
 proc xmlrpc::serve {port} {
-    variable	acceptfd
-
-    set acceptfd [socket -server xmlrpc::serveOnce $port]
-    return $acceptfd
+    return [socket -server xmlrpc::serveOnce $port]
 }
 
 # Accept a new connection
 #
 proc xmlrpc::serveOnce {sock addr port} {
     variable	READSIZE
-
     debug "in serveOnce: addr: $addr"
     debug "in serveOnce: port: $port"
     fconfigure $sock -translation {lf lf} -buffersize $READSIZE
@@ -108,6 +100,12 @@ proc xmlrpc::doRequest {sock} {
     variable	WS
 
     set res [readHeader $sock]
+    if {$res == {}} {
+	puts "---"
+	debug "::doRequest empty header"
+	return
+    }
+
     set headerStatus [lindex $res 0];	# Header + Status
     set body [lindex $res 1];		# Body, if any
 
@@ -116,8 +114,20 @@ proc xmlrpc::doRequest {sock} {
 	return [errReturn "Malformed Request"]
     }
 
-    set body [getBody $sock $header $body]
+    # CORS preflight
+    set	RE "OPTIONS"
+    if {[regexp $RE $headerStatus {}]} {
+	set header "HTTP/1.1 204 No Content\n"
+	append header "Access-Control-Allow-Origin: *\n"
+	append header "Access-Control-Allow-Methods: POST, GET, OPTIONS\n"
+	append header "Access-Control-Allow-Headers: Content-Type\n"
 
+	puts -nonewline $sock $header
+	flush $sock
+	catch {close $sock}
+	return
+    }
+    
     set	RE "<\?xml.version=.";			# xml version
     append	RE "\[^\?\]+.\?>$WS*";			# version number
     append	RE "<methodCall>$WS*";			# methodCall tag
@@ -127,45 +137,56 @@ proc xmlrpc::doRequest {sock} {
     append	RE "(.*)";				# parameters, if any
     append	RE "</methodCall>.*";			# end methodCall tag
 
+    set body [getBody $sock $header $body]
     if {![regexp $RE $body {} mname params]} {
 	return [errReturn "Malformed methodCall"]
     }
 
+    debug "::doRequest mname=$mname"
     set args {}
-    set param [string range $params 8 end]
-    set param [string trim $param]
-    while {[string range $param 0 6] == "<param>" ||
-       [string range $param 0 7] == "</param>"} {
-	# check for empty element
-	if {[string range $param 0 7] == "</param>"} {
-	    lappend args {}
+    if {$params == {}} {
+	# waj
+	# legal to have no params i.e. ping
+	if {[catch {set result [eval ::$mname]}]} {
+	    set response [buildFault 100 "eval() failed"]
+	} else {
+	    set response [buildResponse $result]
+	}
+    } else {
+	set param [string range $params 8 end]
+	set param [string trim $param]
+	while {[string range $param 0 6] == "<param>" ||
+	       [string range $param 0 7] == "</param>"} {
+	    # check for empty element
+	    if {[string range $param 0 7] == "</param>"} {
+		lappend args {}
+		set param [string range $param 8 end]
+		set param [string trim $param]
+		continue
+	    }
+
+	    set param [string range $param 7 end]
+	    set param [string trim $param]
+
+	    set res [unmarshall $param]
+	    set param [lindex $res 0]
+	    set el [lindex $res 1]
+	    lappend args $el
+	    if {[string range $param 0 7] != "</param>"} {
+		return [errReturn "Invalid End Param"]
+	    }
 	    set param [string range $param 8 end]
 	    set param [string trim $param]
-	    continue
 	}
-
-	set param [string range $param 7 end]
-	set param [string trim $param]
-
-	set res [unmarshall $param]
-	set param [lindex $res 0]
-	set el [lindex $res 1]
-	lappend args $el
-	if {[string range $param 0 7] != "</param>"} {
-	    return [errReturn "Invalid End Param"]
+	if {$param != "</params>"} {
+	    return [errReturn "Invalid End Params"]
+	}
+	if {[catch {set result [eval ::$mname $args]}]} {
+	    set response [buildFault 100 "eval() failed"]
+	} else {
+	    set response [buildResponse $result]
 	}
-	set param [string range $param 8 end]
-	set param [string trim $param]
     }
-    if {$param != "</params>"} {
-	return [errReturn "Invalid End Params"]
-    }
-    if {[catch {set result [eval ::$mname $args]}]} {
-	set response [buildFault 100 "eval() failed"]
-    } else {
-	set response [buildResponse $result]
-    }
-    debug "in doRequest: response:\n$response"
     puts -nonewline $sock $response
     flush $sock
     catch {close $sock}
@@ -191,6 +212,8 @@ proc buildResponse {result} {
     set	header "HTTP/1.1 200 OK\n"
     append	header "Content-Type: text/xml\n"
     append	header "Content-length: $lenbod\n"
+    # needed for CORS
+    append	header "Access-Control-Allow-Origin: *\n"
 
     set response "$header\n$body"
     return $response
@@ -228,18 +251,18 @@ proc buildFault {errcode errmsg} {
 #
 proc xmlrpc::call {url method methodName params {ntabs 4} {distance 3}} {
     variable	READSIZE
-    variable	response
-    global		readdone
-    global		xmlcall
+    global xmlresponse
+    global xmlreaddone
 
-    set readdone 0
-    set xmlcall 1
     set RE {http://([^:]+):([0-9]+)}
     if {![regexp $RE $url {} host port]} {
 	return [errReturn "Malformed URL"]
     }
 
     set sock [socket $host $port]
+    set xmlreaddone($sock) 0
+    set xmlresponse($sock) {}
+
     fconfigure $sock -translation {lf lf} -buffersize $READSIZE
     fconfigure $sock -blocking off
     if {[catch {set request [buildRequest $method $methodName $params $ntabs $distance]}]} {
@@ -247,11 +270,18 @@ proc xmlrpc::call {url method methodName params {ntabs 4} {distance 3}} {
     }
     puts -nonewline $sock $request
     flush $sock
+
     fileevent $sock readable [list xmlrpc::getResponse $sock]
-    vwait readdone
+    vwait xmlreaddone($sock)
     catch {close $sock}
-    if {$readdone > 0} {
-	return $response
+
+    set ss $xmlreaddone($sock)
+    set rr $xmlresponse($sock)
+    unset xmlreaddone($sock)
+    unset xmlresponse($sock)
+
+    if {$ss > 0} {
+	return $rr
     } else {
 	return [errReturn "xmlrpc::call failed"]
     }
@@ -261,8 +291,8 @@ proc xmlrpc::call {url method methodName params {ntabs 4} {distance 3}} {
 # get and parse the response from the server
 #
 proc xmlrpc::getResponse {sock} {
-    variable	response
-    global		readdone
+    global xmlresponse
+    global xmlreaddone
 
     set res [readHeader $sock]
     set headerStatus [lindex $res 0];	# Header + Status
@@ -270,8 +300,8 @@ proc xmlrpc::getResponse {sock} {
 
     set header [parseHTTPCode $headerStatus]
     set body [getBody $sock $header $body]
-    set response [parseResponse $body]
-    set readdone 1
+    set xmlresponse($sock) [parseResponse $body]
+    set xmlreaddone($sock) 1
 }
 
 # Given a socket to read on,
@@ -285,7 +315,8 @@ proc xmlrpc::getBody {sock header body} {
 
     set expLenl [assoc "Content-Length" $headersl]
     if {$expLenl == {}} {
-	return [errReturn "No Content-Length found"]
+	return {}
+#	return [errReturn "No Content-Length found"]
     }
     set expLen [lindex $expLenl 1]
     set body [readBody $body $expLen $sock]
@@ -301,7 +332,8 @@ proc xmlrpc::readHeader {sock} {
     set buffer ""
     while {1} {
 	if {[catch {set buff [nbRead $sock]}]} {
-	    return [errReturn "Premature eof"]
+	    return {}
+#	    return [errReturn "Premature eof"]
 	}
 	append buffer $buff
 	set nindex [string first "\n\n" $buffer]
@@ -474,16 +506,13 @@ proc xmlrpc::buildRequest {method methodName params {ntabs 4} {distance 2}} {
 	append body "\t\t</params>\n"
     }
     append	body "</methodCall>\n"
-#    set body [regsub -all "\n" $body "\r\n"]
     set lenbod [string length $body]
 
     # build the header
     set	header "POST /$method HTTP/1.0\n"
     append	header "Content-Type: text/xml\n"
     append	header "Content-length: $lenbod\n"
-#    set header [regsub -all "\n" $header "\r\n"]
 
-#    set request "$header\r\n$body"
     set request "$header\n$body"
     return $request
 }
@@ -493,7 +522,8 @@ proc xmlrpc::buildRequest {method methodName params {ntabs 4} {distance 2}} {
 #
 proc xmlrpc::marshall {param {ntabs 0} {distance 1}} {
     if {![validParam $param]} {
-	return [errReturn "Malformed Parameter: $param"]
+	return $param
+#	return [errReturn "Malformed Parameter: $param"]
     }
 
     set strtabs ""
@@ -572,7 +602,8 @@ proc xmlrpc::validParam {param} {
 proc xmlrpc::unmarshall {str} {
     set str [string trim $str]
     if {[string range $str 0 6] != "<value>"} {
-	# check for empty element
+	# waj
+	# check for just </value> element
 	if {[string range $str 0 7] != "</value>"} {
 	    return [errReturn "Bad value tag"]
 	}
@@ -588,44 +619,32 @@ proc xmlrpc::unmarshall {str} {
 	return [errReturn "No beginning tag found: $str"]
     }
 
-    if {$btag == "int" || $btag == "i4"} {
-	set res [umInt $str]
-    } elseif {$btag== "boolean"} {
-	set res [umBool $str]
-    } elseif {$btag == "string"} {
-	set res [umString $str]
-    } elseif {$btag == "double"} {
-	set res [umDouble $str]
-    } elseif {$btag == "dateTime.iso8601"} {
-	set res [umDateTime $str]
-    } elseif {$btag == "base64"} {
-	set res [umBase64 $str]
-    } elseif {$btag == "array"} {
-	set res [umArray $str]
-    } elseif {$btag == "struct"} {
-	set res [umStruct $str]
-    } else {
-	#check for empty element
-	if {[string range $btag 0 1]=={/}} {
-	    set id [string first "]" $str ]
+    # waj
+    switch $btag {
+	int -
+	i4 {set res [umInt $str]}
+	boolean {set res [umBool $str]}
+	string {set res [umString $str]}
+	double {set res [umDouble $str]}
+	dateTime.iso8601 {set res [umDateTime $str]}
+	base64 {res [umBase64 $str]}
+	array {set res [umArray $str]}
+	struct {set res [umStruct $str]}
+
+	"/value" {
+	    # assume string
+	    set id [string first "<" $str ]
 	    if {$id != -1} {
-		set rest [string range $str $id end]
-		set rest [string trim $rest]
-		return [list $rest {}]
+		set vv [string range $str 0 [expr $id-1]]
+		set rr [string range $str $id end]
+		set str "<string>${vv}</string>${rr}"
+		set res [umString $str]
 	    }
 	}
 
-	# return [errReturn "Unknown type: $str"]
-	# assume string
-	set id [string first "<" $str ]
-	if {$id != -1} {
-	    set vv [string range $str 0 [expr $id-1]]
-	    set rr [string range $str $id end]
-	    set str "<string>${vv}</string>${rr}"
-	    set res [umString $str]
-	} else {
-	    return [errReturn "Unknown type: $str"]
-	}
+	"/string" {set res [list [string range $str 9 end] {}]}
+	"/struct" {set res [list [string range $str 9 end] {}]}
+	default {return [errReturn "Unknown type: $str"]}
     }
 
     set rest [lindex $res 0]
@@ -862,14 +881,3 @@ proc xmlrpc::test {} {
     debug "data: $data"
     puts [assoc "first" $data]
 }
-
-#proc bgerror {error} {
-#    global xmlcall
-#    if {$xmlcall} {
-#	global readdone
-#	set readdone -1
-#	set xmlcall 0
-#    }
-#}
-
-#xmlrpc::test
