@@ -861,7 +861,7 @@ proc XPARcvdBlock {xpa cdata param buf len} {
 
 proc XPASendCAT {xpa cdata param} {
     InitError xpa
-    catch {ProcessSendCatalogCmd xpasetbuf $xpa $param {} {}}
+    catch {ProcessSendCatalogCmd xpasetbuf $xpa $param}
     XPACatchError $xpa
 }
 
@@ -894,7 +894,7 @@ proc XPARcvdConsole {xpa cdata param buf len} {
 
 proc XPASendContour {xpa cdata param} {
     InitError xpa
-    catch {ProcessSendContourCmd xpasetbuf $xpa $param}
+    catch {ProcessSendContourCmd xpasetbuf $xpa $param [xparec $xpa datafd] {}}
     XPACatchError $xpa
 }
 
@@ -1094,7 +1094,7 @@ proc XPARcvdFits {xpa cdata param buf len} {
 
 proc XPASendFP {xpa cdata param} {
     InitError xpa
-    catch {ProcessSendFootprintCmd xpasetbuf $xpa $param {} {}}
+    catch {ProcessSendFootprintCmd xpasetbuf $xpa $param}
     XPACatchError $xpa
 }
 
@@ -1872,7 +1872,7 @@ proc XPARcvdSFits {xpa cdata param buf len} {
 
 proc XPASendSIA {xpa cdata param} {
     InitError xpa
-    catch {ProcessSendSIACmd xpasetbuf $xpa $param {} {}}
+    catch {ProcessSendSIACmd xpasetbuf $xpa $param}
     XPACatchError $xpa
 }
 
@@ -2349,5 +2349,19 @@ proc ProcessXPACmd {varname iname} {
 }
 
 proc ProcessSendXPACmd {proc id param {sock {}} {fn {}}} {
-    $proc $id "[XPAInfoResult]\n"
+    global parse
+    set parse(proc) $proc
+    set parse(id) $id
+
+    xpasend::YY_FLUSH_BUFFER
+    xpasend::yy_scan_string $param
+    xpasend::yyparse
 }
+
+proc ProcessXPASendCmdConnect {} {
+    global xpa
+    global parse
+
+    $parse(proc) $parse(id) "[ToYesNo [info exists xpa]]"
+}
+
