@@ -26,6 +26,6 @@ set INT_ 281
 set REAL_ 282
 set STRING_ 283
 set DSS1_ 284
-set DSS2RED_ 285
-set DSS2BLUE_ 286
-set DSS2INFRARED_ 287
+set DSS2_RED_ 285
+set DSS2_BLUE_ 286
+set DSS2_INFRARED_ 287
