@@ -25,12 +25,12 @@ set SEXSTR_ 280
 set INT_ 281
 set REAL_ 282
 set STRING_ 283
-set POSS2RED_ 284
-set POSS2INFRARED_ 285
-set POSS2BLUE_ 286
-set POSS1BLUE_ 287
-set POSS1RED_ 288
+set POSS2UKSTU_RED_ 284
+set POSS2UKSTU_IR_ 285
+set POSS2UKSTU_BLUE_ 286
+set POSS1_BLUE_ 287
+set POSS1_RED_ 288
 set ALL_ 289
 set QUICKV_ 290
-set GSC2_ 291
-set GSC1_ 292
+set PHASE2_GSC2_ 291
+set PHASE2_GSC1_ 292
