@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -23,9 +23,9 @@ class ColorMapInfo {
 protected:
   Colorbar* parent_;
 
-  int id;
-  char* name;
-  char* fileName;
+  int id_;
+  char* name_;
+  char* filename_;
   ColorMapInfo* next_;
   ColorMapInfo* previous_;
 
@@ -35,10 +35,10 @@ public:
 
   Colorbar* parent() {return parent_;}
 
-  const char* getName() {return name;}
-  int getID() {return id;}
+  int id() {return id_;}
+  const char* name() {return name_;}
+  const char* filename() {return filename_;}
   void setName(const char*);
-  const char* getFileName() {return fileName;}
   void setFileName(const char*);
   
   ColorMapInfo* next() 
@@ -54,6 +54,7 @@ public:
   virtual int load() =0;
   virtual int load(const char*) =0;
   virtual int save(const char*) =0;
+  virtual int saveVar(const char*) =0;
 
   virtual unsigned char getRedChar(int, int) =0;
   virtual unsigned char getGreenChar(int, int) =0;
