@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -15,9 +15,6 @@ class BasePolygon : public Marker {
  protected:
   virtual void renderX(Drawable, Coord::InternalSystem, RenderMode) =0;
   virtual void renderPS(PSColorSpace) =0;
-#ifdef MAC_OSX_TK
-  virtual void renderMACOSX() =0;
-#endif
 #ifdef __WIN32
   virtual void renderWIN32() =0;
 #endif
