@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -24,11 +24,6 @@ private:
   void renderPS(PSColorSpace);
   void renderPSGC(PSColorSpace);
 
-#ifdef MAC_OSX_TK
-  void renderMACOSX();
-  void renderMACOSXGC();
-#endif
-
 #ifdef __WIN32
   void renderWIN32();
   void renderWIN32GC();
